pynrc.DetectorOps
=================

.. automodule:: pynrc.DetectorOps

   
   
   .. rubric:: Module Attributes

   .. autosummary::
      :toctree:
   
      channel
      chsize
      detid
      detid_list
      detname
      fastaxis
      mask_act
      mask_channels
      mask_ref
      module
      nff
      nout
      ref_info
      scaid
      scaid_list
      slowaxis
      time_exp
      time_frame
      time_group
      time_int
      time_int_eff
      time_ramp
      time_ramp_eff
      time_row_reset
      time_total
      time_total_int1
      time_total_int2
      times_group_avg
      wind_mode
      x0
      xpix
      y0
      ypix
   
   

   
   
   

   
   
   

   
   
   



